﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;

namespace WebAPIJquery
{
    /// <summary>
    /// 아이템
    /// </summary>
    public class UserData
    {
        public int Id { get; set; }
        public string Name { get; set; }
        public DateTime WriteDate { get; set; }

        public UserData(int nId, string sName, DateTime dateWrite)
        {
            this.Id = nId;
            this.Name = sName;
            this.WriteDate = dateWrite;
        }
    }//end UserData

    public sealed class CList
    {
        #region 싱글톤 처리
        private static readonly CList m_instance = new CList();

        private CList()
        {
            List = new List<UserData>();
        }

        /// <summary>
        /// 
        /// </summary>
        public static CList Instance
        {
            get
            {
                return m_instance;
            }
        }
        #endregion

        /// <summary>
        /// 사용할 리스트
        /// </summary>
        private List<UserData> List = null;

        /// <summary>
        /// 리스트를 받는다.
        /// </summary>
        /// <returns></returns>
        public List<UserData> GetList()
        {
            return this.List;
        }

        /// <summary>
        /// 지정한 인덱스의 아이템을 가지고 온다.
        /// </summary>
        /// <param name="nIndex"></param>
        /// <returns></returns>
        public UserData GetItem(int nIndex)
        {
            return this.List[nIndex];
        }
        
        /// <summary>
        /// 데이터를 추가 한다.
        /// </summary>
        /// <param name="nId"></param>
        /// <param name="sName"></param>
        /// <param name="dateWrite"></param>
        public void Add(int nId, string sName, DateTime dateWrite)
        {
            this.Add(new UserData(nId, sName, dateWrite));
        }

        public void Add(UserData oData)
        {
            this.List.Add(oData);
        }

        /// <summary>
        /// 지정한 인덱스의 아이템을 지웁니다.
        /// </summary>
        /// <param name="nIndex"></param>
        /// <returns></returns>
        public void Remove(int nIndex)
        {
            this.List.RemoveAt(nIndex);
        }
    }//end CList
}